<?php

/**
 * Security class for Workflow module.
 * You should never forget to call 'enable'
 * public method to enable security before
 * executing process code.
 *
 * @author Pedro Eugênio Rocha
 * @package Security
 * @static
 */
class Security {

	/**
	 * @var boolean $_protection Stores the current security mode.
	 * @access private
	 * @static
	 */
	private static $_protection = false;


	/**
	 * Disallow the instantiation of this class.
	 * @access public
	 * @return void
	 */
	public function __construct() {
		throw new Exception("Oops! Static only class.");
	}


	/**
	 * Returns the current security mode.
	 * @access public
	 * @return boolean
	 */
	public static function isEnabled() {
		return self::$_protection;
	}


	/**
	 * Change to secured mode.
	 * @access public
	 * @return boolean
	 * @static
	 */
	public static function enable() {

		if (self::_isAllowed())
			self::$_protection = true;
		else
			throw new Exception('You are not allowed to change security mode.');
		return true;
	}

	/**
	 * Change to unsecured mode.
	 * @access public
	 * @return boolean
	 * @static
	 */
	public static function disable() {

		if (self::_isAllowed())
			self::$_protection = false;
		else
			throw new Exception('You are not allowed to change security mode.');
		return true;
	}


	/**
	 * This function do all the security stuff.
	 * Here we must define in which files we are able
	 * to change the security mode.
	 *
	 * @access private
	 * @return boolean
	 * @static
	 */
	private static function _isAllowed() {
		$backtrace = debug_backtrace();

		/* TODO - These are not definitive validations */
		/* $backtrace[1] specifies the imediate antecessor function */
		$basedir = dirname($backtrace[1]['file']);

		if ($basedir == dirname(__FILE__))
			return true;
		return false;
	}
}

?>
